=============================
Linux installation
=============================

Machines running Linux can run OpenMSIStream programs interactively, or persistently as daemons.

.. include:: create_conda_39.rst

.. include:: libsodium.rst

.. include:: pip_install_openmsistream.rst

